@@ -8,4 +8,4 @@ mod response_wrapper;
 pub use block_identifier::BlockIdentifier;
 pub use client::UEthers;
 pub use error::UEthersError;
-pub use models::BlockRpcResponse;
+pub use models::{BlockRpcResponse, TransactionRpcResponse};
